import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { AppCommonModule } from '@app/shared/common/app-common.module';
import { UtilsModule } from '@shared/utils/utils.module';
import { FileUploadModule } from 'ng2-file-upload';
import { ModalModule, PopoverModule, TabsModule, TooltipModule, BsDropdownModule } from 'ngx-bootstrap';
import { BsDatepickerModule, BsDatepickerConfig, BsDaterangepickerConfig, BsLocaleService } from 'ngx-bootstrap/datepicker';
import { AutoCompleteModule, EditorModule, FileUploadModule as PrimeNgFileUploadModule, InputMaskModule, PaginatorModule, PickListModule } from 'primeng/primeng';
import { TableModule } from 'primeng/table';
import { TreeModule } from 'primeng/tree';
import { DragDropModule } from 'primeng/dragdrop';
import {TabViewModule} from 'primeng/tabview';
import { TreeDragDropService } from 'primeng/api';
import { ContextMenuModule } from 'primeng/contextmenu';
import { NgxChartsModule } from '@swimlane/ngx-charts';
import { CountoModule } from 'angular2-counto';
import { TextMaskModule } from 'angular2-text-mask';
import { ImageCropperModule } from 'ngx-image-cropper';
import { NgxBootstrapDatePickerConfigService } from 'assets/ngx-bootstrap/ngx-bootstrap-datepicker-config.service';
import { CreateOrEditSubappModalComponent } from './subapp/create-or-edit-subapp-modal.component';
import { SubappComponent } from './subapp/subapp.component';
import { BasicRoutingModule } from './basic-routing.module';
import { CreateOrEditDictionaryTypeModalComponent } from './dictionarytype/create-or-edit-dictionarytype-modal.component';
import { DictionaryTypeComponent } from './dictionarytype/dictionarytype.component';
import { DictionaryComponent } from './dictionary/dictionary.component';
import { CreateOrEditDictionaryModalComponent } from './dictionary/create-or-edit-dictionary-modal.component';
import { RackTypeComponent } from './racktype/racktype.component';
import { CreateOrEditRackTypeModalComponent } from './racktype/create-or-edit-racktype-modal.component';
import { RackAreaComponent } from './rackarea/rackarea.component';
import { CreateOrEditRackAreaModalComponent } from './rackarea/create-or-edit-rackarea-modal.component';
import { RackIdComponent } from './rackid/rackid.component';
import { CreateOrEditRackIdModalComponent } from './rackid/create-or-edit-rackid-modal.component';
import { RackTypeLookupModule } from '@app/shared/lookup/rackTypeLookup/rackType-lookup.module';
import { RackAreaLookupModule } from '@app/shared/lookup/rackAreaLookup/rackArea-lookup.module';
import { RackIdLookupModule } from '@app/shared/lookup/rackIdLookup/rackId-lookup.module';
import { RoleInterfaceComponent } from './roleinterface/roleinterface.component';
import { CreateOrEditRoleInterfaceModalComponent } from './roleinterface/create-or-edit-roleinterface-modal.component';
import { WaferTraceReportComponent } from './waferTraceReport/waferTraceReport.component';
import { WaferAreaComponent } from './waferarea/waferarea.component';
import { CreateOrEditWaferAreaModalComponent } from './waferarea/create-or-edit-waferarea-modal.component';
import { WaferAreaLookupModule } from '@app/shared/lookup/waferAreaLookup/waferArea-lookup.module';
import { WaferAreaFlowComponent } from './waferareaflow/waferareaflow.component';
import { CreateOrEditWaferAreaFlowModalComponent } from './waferareaflow/create-or-edit-waferareaflow-modal.component';
import { WaferSendOutComponent } from './wafersendout/wafersendout.component';
import { WaferCancelSendComponent } from './wafercancelsend/wafercancelsend.component';
import { WaferReceiveComponent } from './waferreceive/waferreceive.component';
import { WaferSelectComponent } from './waferselect/waferselect.component';
import { WaferHistoryModalComponent } from './waferselect/waferhistory-modal.component';
import { AbnormalReportComponent } from './abnormalreport/abnormalreport.component';
import { CheckReportComponent } from './checkreport/checkreport.component';
import { RuncardsystemComponent } from './runcardsystem/runcardsystem.component';

@NgModule({
    imports: [
        FormsModule,
        ReactiveFormsModule,
        CommonModule,
        FileUploadModule,
        ModalModule.forRoot(),
        TabsModule.forRoot(),
        TooltipModule.forRoot(),
        PopoverModule.forRoot(),
        BsDropdownModule.forRoot(),
        BsDatepickerModule.forRoot(),
        BasicRoutingModule,
        UtilsModule,
        AppCommonModule,
        TableModule,
        TreeModule,
        DragDropModule,
        ContextMenuModule,
        PaginatorModule,
        PrimeNgFileUploadModule,
        AutoCompleteModule,
        EditorModule,
        InputMaskModule,
        NgxChartsModule,
        CountoModule,
        TextMaskModule,
        ImageCropperModule,
        TabViewModule,
        RackTypeLookupModule,
        RackAreaLookupModule,
        RackIdLookupModule,
        WaferAreaLookupModule,
        PickListModule
    ],
    declarations: [
        SubappComponent,
        CreateOrEditSubappModalComponent,
        CreateOrEditDictionaryTypeModalComponent,
        DictionaryTypeComponent,
        DictionaryComponent,
        CreateOrEditDictionaryModalComponent,
        RackTypeComponent,
        CreateOrEditRackTypeModalComponent,
        RackAreaComponent,
        CreateOrEditRackAreaModalComponent,
        RackIdComponent,
        CreateOrEditRackIdModalComponent,
        RoleInterfaceComponent,
        CreateOrEditRoleInterfaceModalComponent,
        WaferTraceReportComponent,
        WaferAreaComponent,
        CreateOrEditWaferAreaModalComponent,
        WaferAreaFlowComponent,
        CreateOrEditWaferAreaFlowModalComponent,
        WaferSendOutComponent,
        WaferCancelSendComponent,
        WaferReceiveComponent,
        WaferSelectComponent,
        WaferHistoryModalComponent,
        AbnormalReportComponent,
        CheckReportComponent,
        RuncardsystemComponent
    ],
    providers: [
        TreeDragDropService,
        { provide: BsDatepickerConfig, useFactory: NgxBootstrapDatePickerConfigService.getDatepickerConfig },
        { provide: BsDaterangepickerConfig, useFactory: NgxBootstrapDatePickerConfigService.getDaterangepickerConfig },
        { provide: BsLocaleService, useFactory: NgxBootstrapDatePickerConfigService.getDatepickerLocale }
    ]
})
export class BasicModule { }
