import { Component, EventEmitter, Injector, Output, ViewChild } from '@angular/core';
import { AppComponentBase } from '@shared/common/app-component-base';
import { ModalDirective } from 'ngx-bootstrap';
import { DomSanitizer } from '@angular/platform-browser';
import { FormGroup } from '@angular/forms';
import { FileUploader } from 'ng2-file-upload';
import { CreateOrEditRackTypeDto } from './racktype.model';
import { SelfHttp } from '@app/shared/common/utils/selfHttp.service';

@Component({
    selector: 'createOrEditRackTypeModal',
    templateUrl: './create-or-edit-racktype-modal.component.html'
})
export class CreateOrEditRackTypeModalComponent extends AppComponentBase {

    @ViewChild('createOrEditModal') modal: ModalDirective;
    @Output() modalSave: EventEmitter<any> = new EventEmitter<any>();
    active = false;
    saving = false;
    createOrEditRackTypeDto: CreateOrEditRackTypeDto = new CreateOrEditRackTypeDto();
    public uploader: FileUploader;
    rackType: string;
    isEdit = false;

    constructor(
        injector: Injector, public sanitizer: DomSanitizer, public selfHttp: SelfHttp) {
        super(injector);
    }
    show(rackType?): void {
        const self = this;
        self.active = true;
        if (rackType) {
            this.rackType = rackType;
            this.selfHttp.get('api/RackTypeManage/RackTypeGetEdit', { RackType: this.rackType }, res => {
                this.createOrEditRackTypeDto.RackType = res.result[0].RACKTYPE;
                this.createOrEditRackTypeDto.Description = res.result[0].DESCRIPTION;
                this.createOrEditRackTypeDto.SourceRackType = res.result[0].RACKTYPE;
            });
        }
        self.modal.show();
    }

    onShown(): void {
        document.getElementById('RackType').focus();
    }

    save(): void {
        this.createOrEditRackTypeDto.UserId = this.appSession.getShownLoginName();
        this.selfHttp.post('api/RackTypeManage/CreateOrEditRackType', this.createOrEditRackTypeDto, res => {
            this.notify.info(this.l('SavedSuccessfully'));
            this.close();
            this.modalSave.emit(null);
        });
    }

    close(): void {
        this.rackType = '';
        this.active = false;
        this.createOrEditRackTypeDto = new CreateOrEditRackTypeDto();
        this.isEdit = false;
        this.modal.hide();
    }
}
