import { Component, Injector, ViewChild, OnInit } from '@angular/core';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { SubAppServiceProxy, SubAppDto, RackTypeServiceProxy } from '@shared/service-proxies/service-proxies';
import { Table } from 'primeng/components/table/table';
import * as _ from 'lodash';
import { LazyLoadEvent } from 'primeng/api';
import { Paginator } from 'primeng/primeng';
import { FileDownloadService } from '@shared/utils/file-download.service';
import { RackTypeSerarchInputDto } from './racktype.model';
import { SelfHttp } from '@app/shared/common/utils/selfHttp.service';
import { CreateOrEditRackTypeModalComponent } from './create-or-edit-racktype-modal.component';
import { RackTypeLookupTableModalComponent } from '@app/shared/lookup/rackTypeLookup/rackType-lookup-table-modal.component';

@Component({
    templateUrl: './racktype.component.html',
    animations: [appModuleAnimation()]
})
export class RackTypeComponent extends AppComponentBase implements OnInit {

    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;
    @ViewChild('createOrEditRackTypeModal') createOrEditRackTypeModal: CreateOrEditRackTypeModalComponent;
    @ViewChild('rackTypeLookupTableModal') rackTypeLookupTableModal: RackTypeLookupTableModalComponent;
    advancedFiltersAreShown = false;

    //Filters
    selectedPermission = '';
    filterText = '';
    filterRackType = '';
    Sort = '';
    filterDescription = '';
    filterInsterTime = '';
    filterUpdateTime = '';
    filterLastUser = '';
    rackType = '';
    rackTypeSerarchInputDto = new RackTypeSerarchInputDto();

    constructor(
        injector: Injector,
        private _rackTypeService: RackTypeServiceProxy,
        private _fileDownloadService: FileDownloadService,
        private selfHttp: SelfHttp
    ) {
        super(injector);
    }

    ngOnInit(): void {
    }

    getAll(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        let data = {
            Filter: this.filterText,
            RackType: this.rackType,
            Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
            PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
            PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
        };
        this.selfHttp.get('api/RackTypeManage/RackTypeGetAll', data, res => {
            //20221026 Modify
            let result = JSON.parse(res);
            if (result.result.length > 0) {
                this.primengTableHelper.totalRecordsCount = result.total;
            } else {
                this.primengTableHelper.totalRecordsCount = 0;
            }
            this.primengTableHelper.records = result.result;
            //if (res.result.length > 0) {
            //this.primengTableHelper.totalRecordsCount = res.total;
            //} else {
            //    this.primengTableHelper.totalRecordsCount = 0;
            //}
            //this.primengTableHelper.records = res.result;
        
        });
    }

    exportToExcel(): void {
        this._rackTypeService.getRackTypeToExcel(
            this.filterText,
            this.primengTableHelper.getSorting(this.dataTable),
            this.filterRackType)
            .subscribe(result => {
                this._fileDownloadService.downloadTempFile(result);
            });
    }

    createSubApp(): void {
        this.createOrEditRackTypeModal.show();
    }

    deleteRackType(data: any): void {
        let self = this;
        self.message.confirm('',
            isConfirmed => {
                if (isConfirmed) {
                    this.selfHttp.delete('api/RackTypeManage/DeleteRackType', { RackType: data.RACKTYPE }, res => {
                        this.getAll();
                        abp.notify.success(this.l('SuccessfullyDeleted'));
                    });
                }
            }
        );
    }

    openSelectRackTypeModal() {
        this.rackTypeLookupTableModal.rackType = this.rackType;
        this.rackTypeLookupTableModal.show();
    }

    setRackTypeNull() {
        this.rackType = '';
    }

    getNewRackType() {
        this.rackType = this.rackTypeLookupTableModal.rackType;
    }
}
