import { Component, Injector, ViewChild, OnInit, ElementRef } from '@angular/core';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { SubAppDto, DictionaryTypesServiceProxy, RoleInterfaceServiceProxy } from '@shared/service-proxies/service-proxies';
import { Table } from 'primeng/components/table/table';
import { EntityTypeHistoryModalComponent } from '@app/shared/common/entityHistory/entity-type-history-modal.component';
import * as _ from 'lodash';
import { finalize } from 'rxjs/operators';
import { LazyLoadEvent } from 'primeng/api';
import { Paginator } from 'primeng/primeng';
import { FileDownloadService } from '@shared/utils/file-download.service';
import { CreateOrEditRoleInterfaceModalComponent } from './create-or-edit-roleinterface-modal.component';

@Component({
    templateUrl: './roleInterface.component.html',
    animations: [appModuleAnimation()]
})
export class RoleInterfaceComponent extends AppComponentBase implements OnInit {

    @ViewChild('createOrEditRoleInterfaceModal') createOrEditRoleInterfaceModal: CreateOrEditRoleInterfaceModalComponent;
    @ViewChild('entityTypeHistoryModal') entityTypeHistoryModal: EntityTypeHistoryModalComponent;
    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;

    advancedFiltersAreShown = false;

    //Filters
    selectedPermission = '';
    filterText = '';
    filterUserArea = '';
    filterUserRole = '';
    filterAppRole = '';
    constructor(
        injector: Injector,
        private _roleInterfaceService: RoleInterfaceServiceProxy,
        private _fileDownloadService: FileDownloadService
    ) {
        super(injector);
    }

    ngOnInit(): void {
    }

    getAll(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);

            return;
        }

        this.primengTableHelper.showLoadingIndicator();
        this._roleInterfaceService.getAll(
            this.filterText,
            this.filterUserArea,
            this.filterUserRole,
            this.filterAppRole,
            this.primengTableHelper.getSorting(this.dataTable),
            this.primengTableHelper.getSkipCount(this.paginator, event),
            this.primengTableHelper.getMaxResultCount(this.paginator, event)
        ).pipe(finalize(() => this.primengTableHelper.hideLoadingIndicator())).subscribe(result => {
            this.primengTableHelper.totalRecordsCount = result.totalCount;
            this.primengTableHelper.records = result.items;
            console.log(result);
            this.primengTableHelper.hideLoadingIndicator();
        });
    }

    exportToExcel(): void {
        this._roleInterfaceService.getRoleInterfaceToExcel(
            this.filterText,
            this.filterUserArea,
            this.filterUserRole,
            this.filterAppRole,
            this.primengTableHelper.getSorting(this.dataTable))
            .subscribe(result => {
                this._fileDownloadService.downloadTempFile(result);
            });
    }

    createSubApp(): void {
        this.createOrEditRoleInterfaceModal.show();
    }

    deleteSubApp(subapp: SubAppDto): void {
        let self = this;
        self.message.confirm('',
            isConfirmed => {
                if (isConfirmed) {
                    this._roleInterfaceService.delete(subapp.id).subscribe(() => {
                        this.getAll();
                        abp.notify.success(this.l('SuccessfullyDeleted'));
                    });
                }
            }
        );
    }
}
