import { Component, Injector, ViewChild, OnInit, ElementRef } from '@angular/core';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { RoleListDto, RoleServiceProxy, SubAppServiceProxy, SubAppDto } from '@shared/service-proxies/service-proxies';
import { Table } from 'primeng/components/table/table';
import { CreateOrEditSubappModalComponent } from './create-or-edit-subapp-modal.component';
import { EntityTypeHistoryModalComponent } from '@app/shared/common/entityHistory/entity-type-history-modal.component';
import * as _ from 'lodash';
import { finalize } from 'rxjs/operators';
import { LazyLoadEvent } from 'primeng/api';
import { Paginator } from 'primeng/primeng';
import { FileDownloadService } from '@shared/utils/file-download.service';

@Component({
    templateUrl: './subapp.component.html',
    animations: [appModuleAnimation()]
})
export class SubappComponent extends AppComponentBase implements OnInit {

    @ViewChild('createOrEditSubappModal') createOrEditSubappModal: CreateOrEditSubappModalComponent;
    @ViewChild('entityTypeHistoryModal') entityTypeHistoryModal: EntityTypeHistoryModalComponent;
    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;

    advancedFiltersAreShown = false;

    //Filters
    selectedPermission = '';
    filterText = '';
    filterCode = '';
    filterName = '';
    filterIsEnable = '';

    constructor(
        injector: Injector,
        private _subAppService: SubAppServiceProxy,
        private _fileDownloadService: FileDownloadService
    ) {
        super(injector);
    }

    ngOnInit(): void {
    }

    getSubApps(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);

            return;
        }

        this.primengTableHelper.showLoadingIndicator();
        this._subAppService.getSubApp(
            this.filterText,
            this.filterCode,
            this.filterName,
            this.filterIsEnable,
            this.primengTableHelper.getSorting(this.dataTable),
            this.primengTableHelper.getMaxResultCount(this.paginator, event),
            this.primengTableHelper.getSkipCount(this.paginator, event)
        ).pipe(finalize(() => this.primengTableHelper.hideLoadingIndicator())).subscribe(result => {
            this.primengTableHelper.totalRecordsCount = result.totalCount;
            this.primengTableHelper.records = result.items;
            this.primengTableHelper.hideLoadingIndicator();
        });
    }

    exportToExcel(): void {
        this._subAppService.getSubAppToExcel(
            this.filterText,
            this.primengTableHelper.getSorting(this.dataTable),
            this.filterCode,
            this.filterName,
            this.filterIsEnable)
            .subscribe(result => {
                this._fileDownloadService.downloadTempFile(result);
            });
    }

    createSubApp(): void {
        this.createOrEditSubappModal.show();
    }

    deleteSubApp(subapp: SubAppDto): void {
        let self = this;
        self.message.confirm('',
            isConfirmed => {
                if (isConfirmed) {
                    this._subAppService.deleteSubApp(subapp.id).subscribe(() => {
                        this.getSubApps();
                        abp.notify.success(this.l('SuccessfullyDeleted'));
                    });
                }
            }
        );
    }
}
