import { Component, Injector, ViewChild, OnInit } from '@angular/core';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { SubAppServiceProxy, SubAppDto, RackTypeServiceProxy, WaferReportServiceProxy } from '@shared/service-proxies/service-proxies';
import { Table } from 'primeng/components/table/table';
import * as _ from 'lodash';
import { LazyLoadEvent } from 'primeng/api';
import { Paginator } from 'primeng/primeng';
import { FileDownloadService } from '@shared/utils/file-download.service';
import { WaferSerarchInputDto } from './wafer.model';
import { SelfHttp } from '@app/shared/common/utils/selfHttp.service';
import { WaferHttp } from '@app/shared/common/utils/waferhttp.service';
import { WaferAreaLookupTableModalComponent } from '@app/shared/lookup/waferAreaLookup/waferArea-lookup-table-modal.component';

@Component({
    templateUrl: './waferTraceReport.component.html',
    animations: [appModuleAnimation()]
})
export class WaferTraceReportComponent extends AppComponentBase implements OnInit {

    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;
    @ViewChild('waferAreaLookupTableModal') waferAreaLookupTableModal: WaferAreaLookupTableModalComponent;
    @ViewChild('waferToAreaLookupTableModal') waferToAreaLookupTableModal: WaferAreaLookupTableModalComponent;
    advancedFiltersAreShown = false;

    //Filters
    selectedPermission = '';
    filterText = '';
    filterWafer = '';
    Sort = '';
    filterDescription = '';
    filterInsterTime = '';
    filterUpdateTime = '';
    filterControllot = '';
    filterWaferlot = '';
    filterLastUser = '';
    wafer = '';
    controllot = '';
    location = '';
    toArea = '';
    status = '';
    waferSerarchInputDto = new WaferSerarchInputDto();

    constructor(
        injector: Injector,
        private _rackTypeService: WaferReportServiceProxy,
        private _fileDownloadService: FileDownloadService,
        private waferHttp: WaferHttp
    ) {
        super(injector);
    }

    ngOnInit(): void {
    }

    getAll(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        let data = {
            Filter: this.filterText,
            WaferId: this.wafer,
            Controllot: this.controllot,
            Location: this.location,
            ToArea: this.toArea,
            Status: this.status,
            Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
            PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
            PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
        };
        this.waferHttp.get('api/WaferTraceReportManage/WaferGetAll', data, res => {
            let result = JSON.parse(res);
            if (result.result.length > 0) {
                this.primengTableHelper.totalRecordsCount = result.total;
                } else {
                    this.primengTableHelper.totalRecordsCount = 0;
                }
                this.primengTableHelper.records = result.result;
        });
    }

    exportToExcel(): void {
        this._rackTypeService.getWaferReportToExcel(
            this.filterText,
            this.primengTableHelper.getSorting(this.dataTable),
            this.controllot,
            this.filterWaferlot,
            this.location,
            this.toArea,
            this.status)
            .subscribe(result => {
                this._fileDownloadService.downloadTempFile(result);
            });
    }

    setRackTypeNull() {
        this.wafer = '';
    }

    openSelectLocationModal() {
        this.waferAreaLookupTableModal.code = this.location;
        this.waferAreaLookupTableModal.show();
    }

    openSelectToAreaModal() {
        this.waferToAreaLookupTableModal.code = this.toArea;
        this.waferToAreaLookupTableModal.show();
    }

    setToAreaNull() {
        this.toArea = '';
    }

    setLocationNull() {
        this.location = '';
    }

    getNewLocation() {
        this.location = this.waferAreaLookupTableModal.code;
    }

    getNewToArea() {
        this.toArea = this.waferToAreaLookupTableModal.code;
    }
}
