import { Component, Injector, ViewChild, OnInit } from '@angular/core';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { SubAppServiceProxy, SubAppDto, RackTypeServiceProxy, WaferAreaServiceProxy } from '@shared/service-proxies/service-proxies';
import { Table } from 'primeng/components/table/table';
import * as _ from 'lodash';
import { LazyLoadEvent } from 'primeng/api';
import { Paginator } from 'primeng/primeng';
import { FileDownloadService } from '@shared/utils/file-download.service';
import { SelfHttp } from '@app/shared/common/utils/selfHttp.service';
import { WaferHttp } from '@app/shared/common/utils/waferhttp.service';
import { WaferAreaSerarchInputDto } from './waferarea.model';
import { CreateOrEditWaferAreaModalComponent } from './create-or-edit-waferarea-modal.component';
import { WaferAreaLookupTableModalComponent } from '@app/shared/lookup/waferAreaLookup/waferArea-lookup-table-modal.component';

@Component({
    templateUrl: './waferArea.component.html',
    animations: [appModuleAnimation()]
})
export class WaferAreaComponent extends AppComponentBase implements OnInit {

    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;
    @ViewChild('createOrEditWaferAreaModal') createOrEditWaferAreaModal: CreateOrEditWaferAreaModalComponent;
    @ViewChild('waferAreaLookupTableModal') waferAreaLookupTableModal: WaferAreaLookupTableModalComponent;
    advancedFiltersAreShown = false;

    //Filters
    selectedPermission = '';
    filterText = '';
    filterCode = '';
    Sort = '';
    filterDescription = '';
    filterInsterTime = '';
    filterUpdateTime = '';
    filterLastUser = '';
    code = '';
    controllot = '';
    waferAreaSerarchInputDto = new WaferAreaSerarchInputDto();

    constructor(
        injector: Injector,
        private _waferAreaService: WaferAreaServiceProxy,
        private _fileDownloadService: FileDownloadService,
        private waferHttp: WaferHttp
    ) {
        super(injector);
    }

    ngOnInit(): void {
    }

    getAll(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        let data = {
            Filter: this.filterText,
            Code: this.code,
            Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
            PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
            PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
        };
        this.waferHttp.get('api/WaferTraceAreaManage/WaferAreaGetAll', data, res => {
            let result = JSON.parse(res);
            if (result.result.length > 0) {
            this.primengTableHelper.totalRecordsCount = result.total;
            } else {
                this.primengTableHelper.totalRecordsCount = 0;
            }
            this.primengTableHelper.records = result.result;
        });
    }

    createSubApp(): void {
        this.createOrEditWaferAreaModal.show();
    }

    exportToExcel(): void {
        this._waferAreaService.getWaferAreaToExcel(
            this.filterText,
            this.primengTableHelper.getSorting(this.dataTable),
            this.filterCode)
            .subscribe(result => {
                this._fileDownloadService.downloadTempFile(result);
            });
    }

    deleteWaferArea(data: any): void {
        let self = this;
        self.message.confirm('',
            isConfirmed => {
                if (isConfirmed) {
                    this.waferHttp.delete('api/WaferTraceAreaManage/DeleteRackType', { Code: data.AREACODE }, res => {
                        this.getAll();
                        abp.notify.success(this.l('SuccessfullyDeleted'));
                    });
                }
            }
        );
    }

    openSelectWaferAreaModal() {
        this.waferAreaLookupTableModal.code = this.code;
        this.waferAreaLookupTableModal.show();
    }

    setWaferAreaNull() {
        this.code = '';
    }

    getNewWaferArea() {
        this.code = this.waferAreaLookupTableModal.code;
    }
}
