import { Component, Injector, ViewChild, OnInit } from '@angular/core';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { SubAppServiceProxy, SubAppDto, RackTypeServiceProxy, WaferAreaFlowServiceProxy } from '@shared/service-proxies/service-proxies';
import { Table } from 'primeng/components/table/table';
import * as _ from 'lodash';
import { LazyLoadEvent } from 'primeng/api';
import { Paginator } from 'primeng/primeng';
import { FileDownloadService } from '@shared/utils/file-download.service';
import { SelfHttp } from '@app/shared/common/utils/selfHttp.service';
import { WaferHttp } from '@app/shared/common/utils/waferhttp.service';
import { WaferAreaLookupTableModalComponent } from '@app/shared/lookup/waferAreaLookup/waferArea-lookup-table-modal.component';
import { WaferAreaFlowSerarchInputDto } from './waferareaflow.model';
import { CreateOrEditWaferAreaFlowModalComponent } from './create-or-edit-waferareaflow-modal.component';

@Component({
    templateUrl: './waferAreaFlow.component.html',
    animations: [appModuleAnimation()]
})
export class WaferAreaFlowComponent extends AppComponentBase implements OnInit {

    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;
    @ViewChild('createOrEditWaferAreaFlowModal') createOrEditWaferAreaFlowModal: CreateOrEditWaferAreaFlowModalComponent;
    @ViewChild('waferAreaLookupTableModal') waferAreaLookupTableModal: WaferAreaLookupTableModalComponent;
    advancedFiltersAreShown = false;

    //Filters
    selectedPermission = '';
    filterText = '';
    filterWafer = '';
    Sort = '';
    filterDescription = '';
    filterInsterTime = '';
    filterUpdateTime = '';
    filterLastUser = '';
    filterFromCode = '';
    filterToCode = '';
    fromCode = '';
    toCode = '';
    controllot = '';
    selectArea = '';
    waferAreaFlowSerarchInputDto = new WaferAreaFlowSerarchInputDto();

    constructor(
        injector: Injector,
        private _rackTypeService: WaferAreaFlowServiceProxy,
        private _fileDownloadService: FileDownloadService,
        private waferHttp: WaferHttp
    ) {
        super(injector);
    }

    ngOnInit(): void {
    }

    getAll(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        let data = {
            Filter: this.filterText,
            FromCode: this.fromCode,
            ToCode: this.toCode,
            Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
            PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
            PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
        };
        this.waferHttp.get('api/WaferTraceAreaFlowManage/WaferAreaFlowGetAll', data, res => {
            let result = JSON.parse(res);
            if (result.result.length > 0) {
            this.primengTableHelper.totalRecordsCount = result.total;
            } else {
                this.primengTableHelper.totalRecordsCount = 0;
            }
            this.primengTableHelper.records = result.result;
        });
    }

    createSubApp(): void {
        this.createOrEditWaferAreaFlowModal.show();
    }

    exportToExcel(): void {
        this._rackTypeService.getWaferAreaFlowToExcel(
            this.filterText,
            this.primengTableHelper.getSorting(this.dataTable),
            this.filterFromCode,
            this.filterToCode)
            .subscribe(result => {
                this._fileDownloadService.downloadTempFile(result);
            });
    }

    deleteWaferAreaFlow(data: any): void {
        let self = this;
        self.message.confirm('',
            isConfirmed => {
                if (isConfirmed) {
                    this.waferHttp.delete('api/WaferTraceAreaFlowManage/DeleteWaferAreaFlow', { FromCode: data.FROMCODE, ToCode: data.TOCODE}, res => {
                        this.getAll();
                        abp.notify.success(this.l('SuccessfullyDeleted'));
                    });
                }
            }
        );
    }

    openSelectFromAreaModal() {
        this.waferAreaLookupTableModal.code = this.fromCode;
        this.waferAreaLookupTableModal.show();
        this.selectArea = 'from';
    }
    openSelectToAreaModal() {
        this.waferAreaLookupTableModal.code = this.toCode;
        this.waferAreaLookupTableModal.show();
        this.selectArea = 'to';
    }
    setFromAreaNull() {
        this.fromCode = '';
    }
    setToAreaNull() {
        this.toCode = '';
    }
    getNewArea() {
        if (this.selectArea === 'from') {
            this.fromCode = this.waferAreaLookupTableModal.code;
        } else if ( this.selectArea === 'to') {
            this.toCode = this.waferAreaLookupTableModal.code;
        }
    }
}
