import { Component, ViewChild, Injector, Output, EventEmitter, ViewEncapsulation, Input} from '@angular/core';
import { ModalDirective } from 'ngx-bootstrap';
import { AppComponentBase } from '@shared/common/app-component-base';
import { Table } from 'primeng/components/table/table';
import { Paginator } from 'primeng/components/paginator/paginator';
import { LazyLoadEvent } from 'primeng/components/common/lazyloadevent';
import { SelfHttp } from '@app/shared/common/utils/selfHttp.service';
@Component({
    selector: 'rackIdLookupTableModal',
    styleUrls: ['../style/name-lookup-table-modal.component.less'],
    encapsulation: ViewEncapsulation.None,
    templateUrl: './rackId-lookup-table-modal.component.html'
})
export class RackIdLookupTableModalComponent extends AppComponentBase {

    @ViewChild('createOrEditModal') modal: ModalDirective;
    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;


    filterRackType = '';
    filterRackArea = '';
    filterDescription = '';
    filterRackId = '';
    Sort = '';
    filterIsEnable = '';
    filterText = '';
    rackId: string;
    rackType: '';
    rackArea: '';
    description: string;
    @Input() service;

    @Output() modalSave: EventEmitter<any> = new EventEmitter<any>();

    active = false;
    saving = false;

    constructor(
        injector: Injector,
        private selfHttp: SelfHttp
    ) {
        super(injector);
    }

    show(): void {
        this.active = true;
        this.paginator.rows = 5;
        this.getAll();
        this.modal.show();
    }


    getAll(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        let data = {
            Filter: this.filterText,
            RackType: this.filterRackType,
            RackArea: this.filterRackArea,
            RackId: this.filterRackId,
            Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
            PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
            PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
        };
        this.selfHttp.get('api/RackIdManage/RackIdGetAll', data, res => {
            //20221026 Modify
            let result = JSON.parse(res);
            if (result.result.length > 0) {
                this.primengTableHelper.totalRecordsCount = result.total;
            } else {
                this.primengTableHelper.totalRecordsCount = 0;
            }
            this.primengTableHelper.records = result.result;
            //if (res.result.length > 0) {
            //this.primengTableHelper.totalRecordsCount = res.total;
            //} else {
            //    this.primengTableHelper.totalRecordsCount = 0;
            //}
            //this.primengTableHelper.records = res.result;
        });
    }


    reloadPage(): void {
        this.paginator.changePage(this.paginator.getPage());
    }

    setAndSave(res) {
        this.rackId = res.RACKID;
        this.rackArea = res.RACKAREA;
        this.rackType = res.RACKTYPE;
        this.active = false;
        this.modal.hide();
        this.modalSave.emit(null);
    }

    close(): void {
        this.active = false;
        this.modal.hide();
        this.modalSave.emit(null);
    }
}
