import { Component, ViewChild, Injector, Output, EventEmitter, ViewEncapsulation, Input} from '@angular/core';
import { ModalDirective } from 'ngx-bootstrap';
import { AppComponentBase } from '@shared/common/app-component-base';
import { Table } from 'primeng/components/table/table';
import { Paginator } from 'primeng/components/paginator/paginator';
import { LazyLoadEvent } from 'primeng/components/common/lazyloadevent';
import { SelfHttp } from '@app/shared/common/utils/selfHttp.service';
import { WaferHttp } from '@app/shared/common/utils/waferhttp.service';
@Component({
    selector: 'waferAreaLookupTableModal',
    styleUrls: ['../style/name-lookup-table-modal.component.less'],
    encapsulation: ViewEncapsulation.None,
    templateUrl: './waferArea-lookup-table-modal.component.html'
})
export class WaferAreaLookupTableModalComponent extends AppComponentBase {

    @ViewChild('createOrEditModal') modal: ModalDirective;
    @ViewChild('dataTable') dataTable: Table;
    @ViewChild('paginator') paginator: Paginator;

    filterCode = '';
    filterDescription = '';
    Sort = '';
    filterText = '';
    code: string;
    description: string;
    toCode = '';
    @Input() service;

    @Output() modalSave: EventEmitter<any> = new EventEmitter<any>();

    active = false;
    saving = false;

    constructor(
        injector: Injector,
        private waferHttp: WaferHttp
    ) {
        super(injector);
    }

    show(): void {
        this.active = true;
        this.paginator.rows = 5;
        this.getAll();
        this.modal.show();
    }

    showToArea(code: string): void {
        this.active = true;
        this.paginator.rows = 5;
        this.getToArea(code);
        this.modal.show();
    }

    showToAreaByFromArea(code: string): void {
        this.active = true;
        this.paginator.rows = 5;
        this.toCode = code;
        this.getToAreaByFromArea(code);
        this.modal.show();
    }

    getAll(event?: LazyLoadEvent): void {
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        if (!this.toCode) {
            let data = {
                Filter: this.filterText,
                Code: this.filterCode,
                Description: this.filterDescription,
                Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
                PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
                PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
            };
            this.waferHttp.get('api/WaferTraceAreaManage/WaferAreaGetAll', data, res => {
                let result = JSON.parse(res);
                if (result.result.length > 0) {
                this.primengTableHelper.totalRecordsCount = result.total;
                } else {
                    this.primengTableHelper.totalRecordsCount = 0;
                }
                this.primengTableHelper.records = result.result;
            });
        } else {
            let data = {
                Filter: this.filterText,
                FromCode: this.toCode,
                Description: this.filterDescription,
                Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
                PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
                PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
            };
            this.waferHttp.get('api/WaferTraceAreaManage/GetToAreaByFromArea', data, res => {
                let result = JSON.parse(res);
                if (result.result.length > 0) {
                this.primengTableHelper.totalRecordsCount = result.total;
                } else {
                    this.primengTableHelper.totalRecordsCount = 0;
                }
                this.primengTableHelper.records = result.result;
            });
        }
    }

    getToArea(code: string, event?: LazyLoadEvent): void {
        let data = {
            Filter: this.filterText,
            FromCode: code,
            Description: this.filterDescription,
            Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
            PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
            PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
        };
        this.waferHttp.get('api/WaferTraceAreaManage/GetToArea', data, res => {
            let result = JSON.parse(res);
            if (result.result.length > 0) {
            this.primengTableHelper.totalRecordsCount = result.total;
            } else {
                this.primengTableHelper.totalRecordsCount = 0;
            }
            this.primengTableHelper.records = result.result;
        });
    }

    getToAreaByFromArea(code: string, event?: LazyLoadEvent): void {
        let data = {
            Filter: this.filterText,
            FromCode: code,
            Description: this.filterDescription,
            Sort: this.primengTableHelper.getSorting(this.dataTable) ? this.primengTableHelper.getSorting(this.dataTable) : '',
            PageSize: this.primengTableHelper.getMaxResultCount(this.paginator, event),
            PageIndex: this.primengTableHelper.getSkipCount(this.paginator, event)
        };
        this.waferHttp.get('api/WaferTraceAreaManage/GetToAreaByFromArea', data, res => {
            let result = JSON.parse(res);
            if (result.result.length > 0) {
            this.primengTableHelper.totalRecordsCount = result.total;
            } else {
                this.primengTableHelper.totalRecordsCount = 0;
            }
            this.primengTableHelper.records = result.result;
        });
    }

    reloadPage(): void {
        this.paginator.changePage(this.paginator.getPage());
    }

    setAndSave(res) {
        this.code = res.AREACODE;
        this.active = false;
        this.modal.hide();
        this.modalSave.emit(null);
    }

    close(): void {
        this.active = false;
        this.modal.hide();
        this.modalSave.emit(null);
    }
}
